#! /bin/bash
### BEGIN INIT INFO
# Provides:          lirc
# Required-Start:    $remote_fs $syslog
# Required-Stop:     $remote_fs $syslog
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Starts LIRC daemon.
# Description:       LIRC is used to control different
#                    infrared receivers and transceivers.
### END INIT INFO

load_modules ()
{
	MODULES_MISSING=false

	log_daemon_msg "Loading LIRC modules"
	for mod in $*; do
		if [ $mod = "udev" ]; then
			log_end_msg 0
			log_success_msg "Restarted via udev, don't reload modules"
			break
		else
			modprobe $mod 2> /dev/null || MODULES_MISSING=true
		fi
	done
	log_end_msg $?

	if $MODULES_MISSING; then
		log_failure_msg "Unable to load LIRC kernel modules. Verify your"
		log_failure_msg "selected kernel modules in /etc/lirc/hardware.conf"
		START_LIRCMD=false
		START_LIRCD=false
	fi
}

build_remote_args ()
{
	REMOTE_ARGS="$*"

	if [ "${REMOTE_DEVICE[$REMOTE_NUM]}" != "none" ]; then
		REMOTE_ARGS="--device=${REMOTE_DEVICE[$REMOTE_NUM]} $REMOTE_ARGS"
	fi
	if [ -n "${REMOTE_DRIVER[$REMOTE_NUM]}" ] && [ "${REMOTE_DRIVER[$REMOTE_NUM]}" != "none" ]; then
		REMOTE_ARGS="--driver=${REMOTE_DRIVER[$REMOTE_NUM]} $REMOTE_ARGS"
	fi

	if [ $REMOTE_COUNT -ge 2 ]; then
		if [ $REMOTE_NUM -gt 0 ]; then
			REMOTE_ARGS="$REMOTE_ARGS --listen=${LIRC_PORT[$REMOTE_NUM]}"
		else
			for I in $(seq $(($REMOTE_COUNT - 1)) -1 1)
                        do
				REMOTE_ARGS="$REMOTE_ARGS --connect=localhost:${LIRC_PORT[$I]}"
			done
		fi
	fi
	REMOTE_ARGS="--output=${REMOTE_SOCKET[$REMOTE_NUM]} $REMOTE_ARGS --pidfile=${REMOTE_PID[$REMOTE_NUM]}"
	echo $REMOTE_ARGS
}

<<<<<<< TREE
=======
build_transmitter_args ()
{
	TRANSMITTER_ARGS="$*"

	#Transmitters must be explicitly be defined
	if [ ! -z "$TRANSMITTER_DEVICE" ] || [ ! -z "$TRANSMITTER_DRIVER" ]; then
		if [ -n "$TRANSMITTER_DEVICE" ] && [ "$TRANSMITTER_DEVICE" != "none" ]; then
			TRANSMITTER_ARGS="--device=$TRANSMITTER_DEVICE $TRANSMITTER_ARGS"
		fi
		if [ -n "$TRANSMITTER_DRIVER" ] && [ "$TRANSMITTER_DRIVER" != "none" ]; then
			TRANSMITTER_ARGS="--driver=$TRANSMITTER_DRIVER $TRANSMITTER_ARGS"
		fi

		#Now, if we ALSO have a remote defined, add some args
		#To make the second lircd connect
		if [ ! -z "$REMOTE_DEVICE" ] || [ ! -z "$REMOTE_DRIVER" ]; then
			TRANSMITTER_ARGS="$TRANSMITTER_ARGS --connect=localhost:8765 --pidfile=/var/run/lirc/lircd1.pid"
		fi
		TRANSMITTER_ARGS="--output=$TRANSMITTER_SOCKET $TRANSMITTER_ARGS"
	fi
	echo $TRANSMITTER_ARGS
}

>>>>>>> MERGE-SOURCE
. /lib/lsb/init-functions

test -f /usr/sbin/lircd || exit 0
test -f /usr/sbin/lircmd || exit 0

START_LIRCMD=true
START_LIRCD=true
START_IREXEC=true


if [ -f /etc/lirc/hardware.conf ];then
	. /etc/lirc/hardware.conf
fi

if [ ! -f /etc/lirc/lircd.conf ] || grep -q "^#UNCONFIGURED" /etc/lirc/lircd.conf; then
	if [ "$1" = "start" ]; then
		log_success_msg "No valid /etc/lirc/lircd.conf has been found."
		log_success_msg "Remote control support has been disabled."
		log_success_msg "Reconfigure LIRC or manually replace /etc/lirc/lircd.conf to enable."
	fi

	START_LIRCD=false
	START_LIRCMD=false
	START_IREXEC=false
fi

if [ ! -f /etc/lirc/lircmd.conf ] || grep -q "^#UNCONFIGURED" /etc/lirc/lircmd.conf; then
	START_LIRCMD=false
fi

if [ ! -f /etc/lirc/lircrc ] || grep -q "^#UNCONFIGURED" /etc/lirc/lircrc; then
	START_IREXEC=false
fi

#We need default socket locations
<<<<<<< TREE
LEGACY_SOCKET="/dev/lircd"
DEFAULT_SOCKET="/var/run/lirc/lircd"
REMOTE_PID="/var/run/lirc/lircd.pid"

# Get the remote count
REMOTE_COUNT=0
if [ ! -z "${REMOTE_DEVICE[0]}" ]; then
	REMOTE_COUNT=${#REMOTE_DEVICE[*]}
fi

# This section should eventually be removed
# Since there is nothing special about the transmitter variables, define as an additional remote instead
if [ ! -z "$TRANSMITTER_DEVICE" ]; then
	REMOTE[$REMOTE_COUNT]="$TRANSMITTER"
	REMOTE_MODULES="$REMOTE_MODULES $TRANSMITTER_MODULES"
	REMOTE_DRIVER[$REMOTE_COUNT]="$TRANSMITTER_DRIVER"
	REMOTE_DEVICE[$REMOTE_COUNT]="$TRANSMITTER_DEVICE"
	REMOTE_SOCKET[$REMOTE_COUNT]="$TRANSMITTER_SOCKET"
	REMOTE_LIRCD_CONF[$REMOTE_COUNT]="$TRANSMITTER_LIRCD_CONF"
	REMOTE_LIRCD_ARGS[$REMOTE_COUNT]="$TRANSMITTER_LIRCD_ARGS"
	REMOTE_COUNT=$(($REMOTE_COUNT + 1))
fi

if [ $REMOTE_COUNT -eq 0 ] && [ -c $dev ]; then
	REMOTE_DEVICE="$dev"
	REMOTE_COUNT=1
=======
OLD_SOCKET="/dev/lircd"
if [ -z "$REMOTE_SOCKET" ]; then
	REMOTE_SOCKET="/var/run/lirc/lircd"
fi
if [ -z "$TRANSMITTER_SOCKET" ]; then
	TRANSMITTER_SOCKET="/var/run/lirc/lircd"
	#Now, if we ALSO have a remote defined,
	#change the default transmitter socket
	if [ ! -z "$REMOTE_DEVICE" ] || [ ! -z "$REMOTE_DRIVER" ]; then
		TRANSMITTER_SOCKET="${TRANSMITTER_SOCKET}1"
	fi
>>>>>>> MERGE-SOURCE
fi

case "$1" in
	start)
		# Load the modules
		if [ "$LOAD_MODULES" = "true" ] && [ "$START_LIRCD" = "true" ]; then
			load_modules $2 $REMOTE_MODULES $MODULES
		fi

		# Start the lircd instance(s)
		if [ "$START_LIRCD" = "true" ]; then
			# make sure the /var/run/lirc directory exists
			[ -d "/var/run/lirc" ] || mkdir -p "/var/run/lirc"

			log_daemon_msg "Starting remote control daemon(s) : LIRC "

			# loop over all remotes defined - go backwards so the final one can connect to the rest
			for REMOTE_NUM in $(seq $(($REMOTE_COUNT - 1)) -1 0)
			do
				# determine the defaults to use for this remote
				if [ $REMOTE_NUM -gt 0 ]; then
					LEGACY_SOCKET[$REMOTE_NUM]="$LEGACY_SOCKET$REMOTE_NUM"
					DEFAULT_SOCKET[$REMOTE_NUM]="$DEFAULT_SOCKET$REMOTE_NUM"
					REMOTE_PID[$REMOTE_NUM]="/var/run/lirc/lircd$REMOTE_NUM.pid"
					if [ -z ${LIRC_PORT[$REMOTE_NUM]} ]; then
						LIRC_PORT[$REMOTE_NUM]=$((8765 + $REMOTE_NUM))
					fi
				fi

				# if no socket was specified, use the default
				if [ -z ${REMOTE_SOCKET[$REMOTE_NUM]} ]; then
					REMOTE_SOCKET[$REMOTE_NUM]=${DEFAULT_SOCKET[$REMOTE_NUM]}
				fi

				# call build_remote_args
				CURRENT_LIRCD_ARGS=`build_remote_args ${REMOTE_LIRCD_ARGS[$REMOTE_NUM]}`

				# launch the lircd daemon with the supplied arguments
				start-stop-daemon --start --quiet --oknodo --pidfile ${REMOTE_PID[$REMOTE_NUM]} --exec /usr/sbin/lircd -- $CURRENT_LIRCD_ARGS < /dev/null
				# If lircd created the new socket and its not the same as the legacy socket, link the legacy socket to the newly created one
				if [ -S "${REMOTE_SOCKET[$REMOTE_NUM]}" -a "${LEGACY_SOCKET[$REMOTE_NUM]}" != "${REMOTE_SOCKET[$REMOTE_NUM]}" ]; then
					rm -f ${LEGACY_SOCKET[$REMOTE_NUM]} && ln -s ${REMOTE_SOCKET[$REMOTE_NUM]} ${LEGACY_SOCKET[$REMOTE_NUM]}
				fi
			done
			log_end_msg $?
		fi

		if [ "$START_LIRCMD" = "true" ]; then
			[ -d "/var/run/lirc" ] || mkdir -p "/var/run/lirc"
			log_daemon_msg "Starting remote control mouse daemon : LIRCMD "
			start-stop-daemon --start --quiet --oknodo --exec /usr/sbin/lircmd < /dev/null
			log_end_msg $?
		fi

		if [ "$START_IREXEC" = "true" ]; then
			[ -d "/var/run/lirc" ] || mkdir -p "/var/run/lirc"
			log_daemon_msg "Starting execution daemon: irexec"
			start-stop-daemon --start --quiet --oknodo --exec /usr/bin/irexec -- -d /etc/lirc/lircrc < /dev/null
			log_end_msg $?
		fi
		;;
	stop)
		if [ "$START_IREXEC" = "true" ]; then
			log_daemon_msg "Stopping execution daemon: irexec"
			start-stop-daemon --stop --quiet --exec /usr/bin/irexec
			log_end_msg $?
		fi

		if [ "$START_LIRCMD" = "true" ]; then
			log_daemon_msg "Stopping remote control mouse daemon: LIRCMD"
			start-stop-daemon --stop --quiet --exec /usr/sbin/lircmd
			log_end_msg $?
		fi

		if [ "$START_LIRCD" = "true" ]; then
			log_daemon_msg "Stopping remote control daemon(s): LIRC"
			start-stop-daemon --stop --quiet --exec /usr/sbin/lircd
			log_end_msg $?
			[ -h "$LEGACY_SOCKET" ] && rm -f $LEGACY_SOCKET
			[ -h "${LEGACY_SOCKET}1" ] && rm -f ${LEGACY_SOCKET}1
		fi
		;;
	reload|force-reload)
		if [ "$START_IREXEC" = "true" ]; then
			start-stop-daemon --stop --quiet --signal 1 --exec /usr/bin/irexec
		fi

		if [ "$START_LIRCD" = "true" ]; then
			start-stop-daemon --stop --quiet --signal 1 --exec /usr/sbin/lircd
		fi

		if [ "$START_LIRCMD" = "true" ]; then
			start-stop-daemon --stop --quiet --signal 1 --exec /usr/sbin/lircmd
		fi
		;;
	restart)
		$0 stop
		#passes parameter $2 which is possibly our udev paramater
		$0 start $2
		;;
	*)
		echo "Usage: /etc/init.d/lircd {start|stop|reload|restart|force-reload}"
	exit 1
esac

exit 0
